.. _rdflib_graph: The ``rdflib`` Graph

====================
The ``rdflib`` Graph
====================
.. module rdflib.graph

The :class:`~rdflib.graph.Graph` class
--------------------------------------
.. autoclass:: rdflib.graph.Graph
    :members:
    :noindex:

.. autoclass:: rdflib.graph.ConjunctiveGraph
    :noindex:

Working with ``rdflib`` graphs
-------------------------------
.. automodule:: rdflib.graph

